@@ -62,7 +62,9 @@ shinyUI(fluidPage(
                     )
                 ),
                 uiOutput("metrSelPat"),
+                actionButton("metrSelPatAll", label="(De)Select All"),
                 uiOutput("metrSelStruct"),
+                actionButton("metrSelStructAll", label="(De)Select All"),
                 selectizeInput("metrSortBy", label=h5("Sort output table by:"),
                               choices=c("Value"=1,
                                         "Structure"=2,
@@ -77,7 +79,9 @@ shinyUI(fluidPage(
                              list("By patient"=1,
                                   "By structure"=2)),
                 uiOutput("plotSelPat"),
+                actionButton("plotSelPatAll", label="(De)Select All"),
                 uiOutput("plotSelStruct"),
+                actionButton("plotSelStructAll", label="(De)Select All"),
                 radioButtons("plotPlotVol", label=h5("Plot relative/absolute volume"),
                              list("Relative volume"=1,
                                   "Absolute volume"=2)),
